@@ -23,8 +23,8 @@
 set -e
 
 VER2=2.8.17
-VER3=3.43.0
-VER3X=3430000
+VER3=3.43.2
+VER3X=3430200
 VERZ=1.2.8
 
 nov2=false
@@ -308,7 +308,7 @@ test -r sqlite3/tool/mkshellc.tcl && \
 
 # appendText name clash in sqlite3 shell
 test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
-  -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && perl -pi -e 's/appendText/shAppendText/g' sqlite3/src/shell.c.in
 
 test -r sqlite3/src/shell.c.in &&
@@ -406,7 +406,7 @@ test "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
   -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" \
   -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" \
   -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
-  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
+  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" -a "$VER3" != "3.43.2" \
   && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2007-01-08 23:40:05.000000000 +0100
 +++ sqlite3/src/libshell.c  2007-01-10 18:35:43.000000000 +0100
@@ -590,7 +590,7 @@ test "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" \
 EOD
 
 test "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
-  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && patch sqlite3/src/os_win.h <<'EOD'
 --- sqlite3.orig/src/os_win.h       2018-01-22 19:57:25.000000000 +0100
 +++ sqlite3/src/os_win.h    2018-02-21 21:13:46.000000000 +0100
@@ -670,7 +670,7 @@ test "$VER3" = "3.13.0" -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" \
      warnInmemoryDb = argc==1;
 EOD
 
-test "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+test "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && rm -f sqlite3/src/libshell.c && patch sqlite3/src/libshell.c <<'EOD'
 --- /dev/null	2023-08-23 14:06:59.000000000 +0200
 +++ sqlite3/src/libshell.c	2023-08-23 14:06:59.00000000 +0200
@@ -687,7 +687,7 @@ EOD
 rm -f sqlite3/src/minshell.c
 touch sqlite3/src/minshell.c
 
-test "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
+test "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" -a "$VER3" != "3.43.2" \
   && patch sqlite3/src/minshell.c <<'EOD'
 --- sqlite3.orig/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 +++ sqlite3/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
@@ -714,7 +714,7 @@ test "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
 +}
 EOD
 
-test "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+test "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && cp -p sqlite3/src/shell.c sqlite3/src/minshell.c \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/minshell.c	2023-08-24 21:58:36.000000000 +0200
@@ -808,7 +808,7 @@ test "$VER3" != "3.6.15" -a "$VER3" != "3.6.16" -a "$VER3" != "3.6.17" \
   -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" \
   -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" \
   -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
-  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
+  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" -a "$VER3" != "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/build.c sqlite3/src/build.c
 --- sqlite3.orig/src/build.c	2007-01-09 14:53:04.000000000 +0100
@@ -874,14 +874,14 @@ test "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" -a "$VER3" != "3.8.10" \
   -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" -a "$VER3" != "3.15.1" \
   -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" -a "$VER3" != "3.22.0" \
   -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" -a "$VER3" != "3.42.0" \
-  -a "$VER3" != "3.43.0" \
+  -a "$VER3" != "3.43.0" -a "$VER3" != "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 --- sqlite3.orig/src/tclsqlite.c	2007-04-06 17:02:14.000000000 +0200
 +++ sqlite3/src/tclsqlite.c	2007-04-10 07:47:49.000000000 +0200
 @@ -14,6 +14,7 @@
  **
- ** $Id: mingw64-cross-build.sh,v 1.72 2023/08/25 15:11:06 chw Exp chw $
+ ** $Id: mingw64-cross-build.sh,v 1.73 2023/10/23 13:31:50 chw Exp chw $
  */
 +#ifndef NO_TCL     /* Omit this whole file if TCL is unavailable */
  #include "tcl.h"
@@ -902,7 +902,7 @@ test "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" \
   -o "$VER3" = "3.14.1" -o "$VER3" = "3.15.0" -o "$VER3" = "3.15.1" \
   -o "$VER3" = "3.15.2" -o "$VER3" = "3.19.3" -o "$VER3" = "3.22.0" \
   -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
-  -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/tclsqlite.c    2015-01-16 14:47:26.000000000 +0100
 +++ sqlite3/src/tclsqlite.c 2015-01-19 17:56:26.517386413 +0100
@@ -1076,7 +1076,7 @@ test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
   -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" \
   -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" \
   -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
-  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
+  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" -a "$VER3" != "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
@@ -1229,6 +1229,7 @@ test "$VER3" != "3.7.8" -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" \
   -a "$VER3" != "3.15.0" -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" \
   -a "$VER3" != "3.19.3" -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" \
   -a "$VER3" != "3.32.3" -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
+  -a "$VER3" != "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_hash.c    2007-11-24 01:41:52.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_hash.c 2008-03-16 11:39:57.000000000 +0100
@@ -1578,7 +1579,7 @@ test "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
   -a "$VER3" != "3.14.0" -a "$VER3" != "3.14.1" -a "$VER3" != "3.15.0" \
   -a "$VER3" != "3.15.1" -a "$VER3" != "3.15.2" -a "$VER3" != "3.19.3" \
   -a "$VER3" != "3.22.0" -a "$VER3" != "3.32.2" -a "$VER3" != "3.32.3" \
-  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" \
+  -a "$VER3" != "3.42.0" -a "$VER3" != "3.43.0" -a "$VER3" != "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2008-07-16 16:43:35.000000000 +0200
 +++ sqlite3/ext/rtree/rtree.c	2008-07-17 08:59:53.000000000 +0200
@@ -1628,7 +1629,7 @@ EOD
 
 # patch: fix rtree to be loadable as extension module
 test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
-  -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && perl -pi -e 's/sqlite3_rtree_init/sqlite3_extension_init/g' \
     sqlite3/ext/rtree/rtree.c
 
@@ -1668,7 +1669,7 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" -o "$VER3" = "3.15.0" \
   -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" -o "$VER3" = "3.19.3" \
   -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
-  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_aux.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_aux.c	2011-06-25 06:44:08.000000000 +0200
@@ -1725,6 +1726,7 @@ test "$VER3" = "3.7.8" -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" \
   -o "$VER3" = "3.15.0" -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" \
   -o "$VER3" = "3.19.3" -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" \
   -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c	2011-09-19 20:46:52.000000000 +0200
 +++ sqlite3/ext/fts3/fts3.c	2011-09-20 09:47:40.000000000 +0200
@@ -1765,7 +1767,7 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" -o "$VER3" = "3.15.0" \
   -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" -o "$VER3" = "3.19.3" \
   -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
-  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_expr.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_expr.c	2011-06-25 06:47:00.000000000 +0200
@@ -1947,7 +1949,7 @@ test "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
 EOD
 
 test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
-  -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/loadext.c	2020-06-04 16:01:10.000000000 +0200
 +++ sqlite3/src/loadext.c	2020-06-12 05:47:05.000000000 +0200
@@ -1974,6 +1976,7 @@ test "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
   -o "$VER3" = "3.15.0" -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" \
   -o "$VER3" = "3.19.3" -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" \
   -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c      2014-03-26 10:26:28.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c  2014-03-26 16:54:39.000000000 +0100
@@ -1996,7 +1999,7 @@ test "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
   -o "$VER3" = "3.14.0" -o "$VER3" = "3.14.1" -o "$VER3" = "3.15.0" \
   -o "$VER3" = "3.15.1" -o "$VER3" = "3.15.2" -o "$VER3" = "3.19.3" \
   -o "$VER3" = "3.22.0" -o "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
-  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.42.0" -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/threads.c      2014-10-17 13:38:27.000000000 +0200
 +++ sqlite3/src/threads.c   2014-10-26 13:40:26.000000000 +0100
@@ -2040,7 +2043,7 @@ test "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
   && perl -pi -e 's/ rb\]/ r\]/g' sqlite3/tool/mkopcodec.tcl \
       sqlite3/tool/tostr.tcl sqlite3/tool/addopcodes.tcl
 test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
-  -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && perl -pi -e 's/ rb\]/ r\]/g' sqlite3/tool/mkopcodec.tcl \
       sqlite3/tool/mkccode.tcl
 
@@ -2152,7 +2155,7 @@ test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" \
 EOD
 # rtree using internal core func
 test "$VER3" = "3.32.2" -o "$VER3" = "3.32.3" -o "$VER3" = "3.42.0" \
-  -o "$VER3" = "3.43.0" \
+  -o "$VER3" = "3.43.0" -o "$VER3" = "3.43.2" \
   && patch sqlite3/ext/rtree/rtree.c <<'EOD'
 --- rtree.c.orig	2020-06-04 16:01:10.000000000 +0200
 +++ rtree.c	2020-06-12 11:51:49.000000000 +0200
